.. _synthetic-observations:

Synthetic Observation
=====================

Methods for generating various types of synthetic observations
from simulation data.

.. toctree::
   :maxdepth: 2

   light_cone_generator
   planning_cosmology_simulations
   sunyaev_zeldovich
   ppv_cubes

The following routines have been moved to the `Trident
<http://trident-project.org/>`__ package.

- :ref:`trident:light-ray-generator`

- :ref:`trident:absorption_spectrum`
